///////////////////////////////////////////////////////////////////////////////
// ViewForm.cpp
// ============
// View component of dialog window
//
//  AUTHORL Song Ho Ahn (song.ahn@gmail.com)
// CREATED: 2023-04-12
// UPDATED: 2023-04-20
///////////////////////////////////////////////////////////////////////////////

#include <sstream>
#include "ViewForm.h"
#include "resource.h"
#include "Log.h"
using namespace Win;

///////////////////////////////////////////////////////////////////////////////
// default ctor
///////////////////////////////////////////////////////////////////////////////
ViewForm::ViewForm()
{
}


///////////////////////////////////////////////////////////////////////////////
// default dtor
///////////////////////////////////////////////////////////////////////////////
ViewForm::~ViewForm()
{
}



///////////////////////////////////////////////////////////////////////////////
// initialize all controls
///////////////////////////////////////////////////////////////////////////////
void ViewForm::initControls(HWND handle)
{
    // set all controls
    textKeyDown.set(handle, IDC_TEXT_KEYDOWN);
    textKeyDown.setFont(L"MS Shell Dlg 2", 10);
    textKeyUp.set(handle, IDC_TEXT_KEYUP);
    textKeyUp.setFont(L"MS Shell Dlg 2", 10);
    textMousePos.set(handle, IDC_TEXT_MOUSEPOS);
    textMousePos.setFont(L"MS Shell Dlg 2", 10);
    textWheel.set(handle, IDC_TEXT_WHEEL);
    textWheel.setFont(L"MS Shell Dlg 2", 10);

    radioLeft.set(handle, IDC_RADIO_LEFT);
    radioLeft.setFont(L"MS Shell Dlg 2", 10);
    radioMiddle.set(handle, IDC_RADIO_MIDDLE);
    radioMiddle.setFont(L"MS Shell Dlg 2", 10);
    radioRight.set(handle, IDC_RADIO_RIGHT);
    radioRight.setFont(L"MS Shell Dlg 2", 10);
}



///////////////////////////////////////////////////////////////////////////////
// update textboxs and radios
///////////////////////////////////////////////////////////////////////////////
void ViewForm::updateKeyDown(int key)
{
    std::wstringstream wss;
    wss << L"WM_KEYDOWN: " << key << std::ends;
    textKeyDown.setText(wss.str().c_str());
}

void ViewForm::updateKeyUp(int key)
{
    std::wstringstream wss;
    wss << L"WM_KEYUP: " << key << std::ends;
    textKeyUp.setText(wss.str().c_str());
}

void ViewForm::updateMousePosition(int x, int y)
{
    std::wstringstream wss;
    wss << L"Position: (" << x << L", " << y << L")" << std::ends;
    textMousePos.setText(wss.str().c_str());
}

void ViewForm::updateMouseDown(int button)
{
    if(button == 1)
        radioLeft.check();
    else if(button == 2)
        radioMiddle.check();
    else if(button == 3)
        radioRight.check();
    else
    {
        radioLeft.uncheck();
        radioMiddle.uncheck();
        radioRight.uncheck();
    }
}

void ViewForm::updateMouseUp(int button)
{
    if(button == 1)
        radioLeft.uncheck();
    else if(button == 2)
        radioMiddle.uncheck();
    else if(button == 3)
        radioRight.uncheck();
}

void ViewForm::updateMouseWheel(int delta)
{
    std::wstringstream wss;
    wss << L"Wheel Delta: " << delta << std::ends;
    textWheel.setText(wss.str().c_str());
}
